fn on_create_room(
    context: &Context,
    id: String,
    relay: String,
    transfer_name: String,
    is_local: bool
) -> Status
Handles the create room packet.

This function is called when a create room packet is received. It creates a room on the specified relay and sends the necessary information to the server.

Arguments

  • context - The context of the sender.
  • id - The ID of the room.
  • relay - The URL of the relay.
  • transfer_name - The name of the transfer.
  • is_local - A boolean indicating whether the room is local.

Returns

A Status representing the result of the operation.