fn on_error(message: String) -> Status
Handles errors by returning a Status with the error message.

Arguments

  • message - The error message.

Returns

A Status indicating the error with the error message.