fn on_join_room(context: &Context, size: Option<usize>) -> Status
Handle the join room packet.

This function is responsible for handling the join room packet received from the receiver. It checks if the size of the room is provided and returns an error if it is not. It then generates the public key and signs it with the HMAC key. It sends the handshake packet to the receiver.

Arguments

  • context - The sender context.
  • size - The size of the room.

Returns

A Status representing the result of the operation.

Errors

Returns an error if the join room packet is invalid.